@@ -62,6 +62,7 @@ class FfmpegProcess:
 
         input_file_info = FileInfoProvider(filepath)
         duration_secs = int(input_file_info.get_duration())
+        print(f"DURATION: {duration_secs}")
 
         progress_bar = tqdm(
             total=duration_secs,
@@ -76,7 +77,8 @@ class FfmpegProcess:
                 line = self._process.stdout.readline().decode("utf-8")
                 # out_time_ms=3505000
                 if "out_time_ms" in line:
-                    seconds_processed = int(line[12:]) / 1000
+                    print(f"Line: {line}")
+                    seconds_processed = int(line.strip()[12:]) / 1000
                     print(f"Processed: {seconds_processed}")
                     seconds_increase = seconds_processed - previous_seconds_processed
                     print(f"INCREASE: {seconds_increase}")
